@@ -17,14 +17,18 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
+
+#include <config.h>
 #include <unistd.h>
 #include <string.h>
 #include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
+#include <gio/gio.h>
 
 #include "comics-document.h"
 #include "ev-document-misc.h"
 #include "ev-document-thumbnails.h"
+#include "ev-file-helpers.h"
 
 struct _ComicsDocumentClass
 {
@@ -58,11 +62,8 @@ static char**     extract_argv                   (EvDocument *document,
 						  gint page);
 
 
-G_DEFINE_TYPE_WITH_CODE (
-	ComicsDocument, comics_document, G_TYPE_OBJECT,
+EV_BACKEND_REGISTER_WITH_CODE (ComicsDocument, comics_document,
 	{
-		G_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT,
-				       comics_document_document_iface_init);
 		G_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_THUMBNAILS,
 				       comics_document_document_thumbnails_iface_init);
 	} );
@@ -84,6 +85,8 @@ comics_regex_quote (const char *s)
 	case ']':
 	case '*':
 	case '\\':
+	    *d++ = '\\';
+	    break;
 	case '\'':
 	    *d++ = '\'';
 	    *d++ = '\\';
@@ -106,7 +109,10 @@ comics_document_load (EvDocument *document,
 {
 	ComicsDocument *comics_document = COMICS_DOCUMENT (document);
 	GSList *supported_extensions;
-	gchar *list_files_command = NULL, *stdout, *quoted_file, *mime_type;
+	GFile *file;
+	GFileInfo *file_info;
+	gchar *list_files_command = NULL, *std_out, *quoted_file;
+	const gchar *mime_type = NULL;
 	gchar **cbr_files;
 	gboolean success;
 	int i, retval;
@@ -115,7 +121,14 @@ comics_document_load (EvDocument *document,
 	g_return_val_if_fail (comics_document->archive != NULL, FALSE);
 
 	quoted_file = g_shell_quote (comics_document->archive);
-	mime_type = gnome_vfs_get_mime_type (uri);
+	file = g_file_new_for_uri (uri);
+	file_info = g_file_query_info (file,
+				       G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+				       0, NULL, NULL);
+	if (file_info != NULL) {
+		mime_type = g_file_info_get_content_type (file_info);
+	}
+	g_object_unref (file);
 
 	/* FIXME, use proper cbr/cbz mime types once they're
 	 * included in shared-mime-info */
@@ -133,26 +146,25 @@ comics_document_load (EvDocument *document,
 		comics_document->regex_arg = TRUE;
 	}
 
+	g_object_unref (file_info);
 	g_free (quoted_file);
 
 	/* Get list of files in archive */
 	success = g_spawn_command_line_sync (list_files_command,
-					     &stdout, NULL, &retval, error);
+					     &std_out, NULL, &retval, error);
 	g_free (list_files_command);
 
 	if (!success) {
-		g_free (mime_type);
 		return FALSE;
 	} else if (retval != 0) {
 		g_set_error (error,
 			     EV_DOCUMENT_ERROR,
 			     EV_DOCUMENT_ERROR_INVALID,
 			     _("File corrupted."));
-		g_free (mime_type);
 		return FALSE;
 	}
 
-	cbr_files = g_strsplit (stdout, "\n", 0);
+	cbr_files = g_strsplit (std_out, "\n", 0);
 	supported_extensions = get_supported_image_extensions ();
 	for (i = 0; cbr_files[i] != NULL; i++) {
 		gchar *suffix = g_strrstr (cbr_files[i], ".");
@@ -173,8 +185,7 @@ comics_document_load (EvDocument *document,
 		g_free (suffix);
 	}
 
-	g_free (stdout);
-	g_free (mime_type);
+	g_free (std_out);
 	g_strfreev (cbr_files);
 	g_slist_foreach (supported_extensions, (GFunc) g_free, NULL);
 	g_slist_free (supported_extensions);
